==> tuia-client-0.2.62-20170823.115958-6-sources.jar: cn/com/tuia/advert/model/ObtainAdvertReqLogExt.java <==
/**
 * Project Name:tuia-clent<br>
 * File Name:ObtainAdvertExReq.java<br>
 * Package Name:cn.com.tuia.advert.model<br>
 * Date:2016年6月16日下午5:14:51<br>
 * Copyright (c) 2016, duiba.com.cn All Rights Reserved.
 */

package cn.com.tuia.advert.model;

import java.io.Serializable;

/**
 * ClassName: ObtainAdvertReqLogExt <br/>
 * Function: 兑吧请求广告接口的请求日志扩展对象，一些基于请求对象的日志扩展属性. <br/>
 * Reason: <br/>
 * date: 2017年1月4日 下午5:14:51 <br/>
 *
 * @author cdm
 * @version
 * @since JDK 1.7
 */
public class ObtainAdvertReqLogExt extends ObtainAdvertReq implements Serializable {

    private static final long serialVersionUID = 7408303732217597930L;

    /** 素材ID */
    private Long              materialId;

    /** 实际出价(分). */
    private Long              fee;
    /** 目标出价(分). */
    private Long              aFee;

    /** 计费方式 @ChargeTypeEnum */
    private String            chargeType;

    /** 设备价格区间 */
    private String            priceSection;

    /** 发券次序，该用户当日发券次数 */
    private Long              putIndex;

    /** 城市 */
    private String            cityId;

    /** 手机类型 */
    private String            model;

    /** 活动订单ID */
    private String            activityOrderId;

    /** 发券时间点 */
    private String            hour;

    /**
     * 定向配置ID
     */
    private Long              orientationId;

    /**
     * 直投类型
     */
    private int deliveryType = 1;

    private Long mediaId;

    private Long pageId;

    private Long positionId;

    /**
     * chargeType.
     *
     * @return the chargeType
     */
    public String getChargeType() {
        return chargeType;
    }

    /**
     * chargeType.
     *
     * @param chargeType the chargeType to set
     */
    public void setChargeType(String chargeType) {
        this.chargeType = chargeType;
    }

    public Long getOrientationId() {
        return orientationId;
    }

    public void setOrientationId(Long orientationId) {
        this.orientationId = orientationId;
    }

    public String getPriceSection() {
        return priceSection;
    }

    public void setPriceSection(String priceSection) {
        this.priceSection = priceSection;
    }

    public String getActivityOrderId() {
        return activityOrderId;
    }

    public void setActivityOrderId(String activityOrderId) {
        this.activityOrderId = activityOrderId;
    }

    public String getModel() {
        return model;
    }

    public void setModel(String model) {
        this.model = model;
    }

    public Long getPutIndex() {
        return putIndex;
    }

    public void setPutIndex(Long putIndex) {
        this.putIndex = putIndex;
    }

    public String getCityId() {
        return cityId;
    }

    public void setCityId(String cityId) {
        this.cityId = cityId;
    }

    public Long getFee() {
        return fee;
    }

    public void setFee(Long fee) {
        this.fee = fee;
    }

    /**
     * materialId.
     *
     * @return the materialId
     * @since JDK 1.6
     */
    public Long getMaterialId() {
        return materialId;
    }

    /**
     * materialId.
     *
     * @param materialId the materialId to set
     * @since JDK 1.6
     */
    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }

    public String getHour() {
        return hour;
    }

    public void setHour(String hour) {
        this.hour = hour;
    }

    public Long getaFee() {
        return aFee;
    }

    public void setaFee(Long aFee) {
        this.aFee = aFee;
    }

    public int getDeliveryType() {
        return deliveryType;
    }

    public void setDeliveryType(int deliveryType) {
        this.deliveryType = deliveryType;
    }

    public Long getMediaId() {
        return mediaId;
    }

    public void setMediaId(Long mediaId) {
        this.mediaId = mediaId;
    }

    public Long getPageId() {
        return pageId;
    }

    public void setPageId(Long pageId) {
        this.pageId = pageId;
    }

    public Long getPositionId() {
        return positionId;
    }

    public void setPositionId(Long positionId) {
        this.positionId = positionId;
    }
}

==> tuia-client-0.5.8-20181217.021127-11-sources.jar: cn/com/tuia/advert/model/ObtainAdvertReqLogExt.java <==
/**
 * Project Name:tuia-clent<br>
 * File Name:ObtainAdvertExReq.java<br>
 * Package Name:cn.com.tuia.advert.model<br>
 * Date:2016年6月16日下午5:14:51<br>
 * Copyright (c) 2016, duiba.com.cn All Rights Reserved.
 */

package cn.com.tuia.advert.model;

import java.io.Serializable;

/**
 * ClassName: ObtainAdvertReqLogExt <br/>
 * Function: 兑吧请求广告接口的请求日志扩展对象，一些基于请求对象的日志扩展属性. <br/>
 * Reason: <br/>
 * date: 2017年1月4日 下午5:14:51 <br/>
 *
 * @author cdm
 * @version
 * @since JDK 1.7
 */
public class ObtainAdvertReqLogExt extends ObtainAdvertReq implements Serializable {

    private static final long serialVersionUID = 7408303732217597930L;

    /** 素材ID */
    private Long              materialId;

    /** 实际出价(分). */
    private Long              fee;
    /** 目标出价(分). */
    private Long              aFee;

    /** 计费方式 @ChargeTypeEnum */
    private String            chargeType;

    /** 设备价格区间 */
    private String            priceSection;

    /** 发券次序，该用户当日发券次数 */
    private Long              putIndex;

    /** 城市 */
    private String            cityId;

    /** 手机类型 */
    private String            model;

    /** 活动订单ID */
    private String            activityOrderId;

    /** 发券时间点 */
    private String            hour;

    /**
     * 定向配置ID
     */
    private Long              orientationId;

    //流量来源，1-推啊、2-兑吧
    private Integer flowSource;

    /**
     * 直投类型
     */
    private int deliveryType = 1;

    private Long mediaId;

    private Long pageId;

    private Long positionId;

    /**
     * 折扣率
     */
    private Double discountRate;

    /**
     * 激励广告打得虚拟广告位id
     */
    private Long virtualSlotId;

    //生效的主体类型，1-杭州推啊，2-霍尔果斯推啊
    private Integer effectiveMainType;

    public Long getVirtualSlotId() {
        return virtualSlotId;
    }

    public void setVirtualSlotId(Long virtualSlotId) {
        this.virtualSlotId = virtualSlotId;
    }

    public Integer getEffectiveMainType() {
        return effectiveMainType;
    }

    public void setEffectiveMainType(Integer effectiveMainType) {
        this.effectiveMainType = effectiveMainType;
    }

    public Integer getFlowSource() {
        return flowSource;
    }

    public void setFlowSource(Integer flowSource) {
        this.flowSource = flowSource;
    }

    /**
     * chargeType.
     *
     * @return the chargeType
     */
    public String getChargeType() {
        return chargeType;
    }

    /**
     * chargeType.
     *
     * @param chargeType the chargeType to set
     */
    public void setChargeType(String chargeType) {
        this.chargeType = chargeType;
    }

    public Long getOrientationId() {
        return orientationId;
    }

    public void setOrientationId(Long orientationId) {
        this.orientationId = orientationId;
    }

    public String getPriceSection() {
        return priceSection;
    }

    public void setPriceSection(String priceSection) {
        this.priceSection = priceSection;
    }

    public String getActivityOrderId() {
        return activityOrderId;
    }

    public void setActivityOrderId(String activityOrderId) {
        this.activityOrderId = activityOrderId;
    }

    public String getModel() {
        return model;
    }

    public void setModel(String model) {
        this.model = model;
    }

    public Long getPutIndex() {
        return putIndex;
    }

    public void setPutIndex(Long putIndex) {
        this.putIndex = putIndex;
    }

    public String getCityId() {
        return cityId;
    }

    public void setCityId(String cityId) {
        this.cityId = cityId;
    }

    public Long getFee() {
        return fee;
    }

    public void setFee(Long fee) {
        this.fee = fee;
    }

    /**
     * materialId.
     *
     * @return the materialId
     * @since JDK 1.6
     */
    public Long getMaterialId() {
        return materialId;
    }

    /**
     * materialId.
     *
     * @param materialId the materialId to set
     * @since JDK 1.6
     */
    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }

    public String getHour() {
        return hour;
    }

    public void setHour(String hour) {
        this.hour = hour;
    }

    public Long getaFee() {
        return aFee;
    }

    public void setaFee(Long aFee) {
        this.aFee = aFee;
    }

    public int getDeliveryType() {
        return deliveryType;
    }

    public void setDeliveryType(int deliveryType) {
        this.deliveryType = deliveryType;
    }

    public Long getMediaId() {
        return mediaId;
    }

    public void setMediaId(Long mediaId) {
        this.mediaId = mediaId;
    }

    public Long getPageId() {
        return pageId;
    }

    public void setPageId(Long pageId) {
        this.pageId = pageId;
    }

    public Long getPositionId() {
        return positionId;
    }

    public void setPositionId(Long positionId) {
        this.positionId = positionId;
    }

    public Double getDiscountRate() {
        return discountRate;
    }

    public void setDiscountRate(Double discountRate) {
        this.discountRate = discountRate;
    }
}
